@@ -1,18 +1,19 @@
-/*  Copyright (c) 2003-2007 Xfce Development Team
+/*  Copyright (c) 2003-2012 Xfce Development Team
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,7 +30,7 @@
 
 #include "weather-search.h"
 #include "weather-http.h"
-
+#include "weather-debug.h"
 
 #define BORDER 8
 
@@ -113,6 +114,7 @@ cb_searchdone(const gboolean succeed,
         for (cur_node = cur_node->children; cur_node;
              cur_node = cur_node->next) {
             place = parse_place(cur_node);
+            weather_dump(weather_dump_place, place);
 
             if (place && place->lat && place->lon && place->display_name) {
                 append_result(dialog->result_mdl,
@@ -141,7 +143,6 @@ cb_searchdone(const gboolean succeed,
         }
 
     gtk_tree_view_column_set_title(dialog->column, _("Results"));
-    return;
 }
 
 
@@ -181,10 +182,10 @@ search_cb(GtkWidget *widget,
     g_free(sane_str);
 
     gtk_tree_view_column_set_title(dialog->column, _("Searching..."));
+    g_message("getting http://nominatim.openstreetmap.org%s", url);
     weather_http_receive_data("nominatim.openstreetmap.org", url,
                               dialog->proxy_host, dialog->proxy_port,
                               cb_searchdone, dialog);
-
     g_free(url);
 }
 
@@ -230,11 +231,7 @@ create_search_dialog(GtkWindow *parent,
                                       GTK_RESPONSE_ACCEPT, FALSE);
     gtk_window_set_icon_name(GTK_WINDOW(dialog->dialog), GTK_STOCK_FIND);
 
-#if GTK_CHECK_VERSION(2,14,0)
     dialog_vbox = gtk_dialog_get_content_area(GTK_DIALOG(dialog->dialog));
-#else
-    dialog_vbox = GTK_DIALOG(dialog->dialog)->vbox;
-#endif
 
     vbox = gtk_vbox_new(FALSE, BORDER);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 6);
@@ -396,6 +393,7 @@ cb_geolocation(const gboolean succeed,
 
     geo = parse_geolocation(xmlDocGetRootElement(doc));
     xmlFreeDoc(doc);
+    weather_dump(weather_dump_geolocation, geo);
 
     if (geo == NULL) {
         data->cb(NULL, NULL, NULL, METRIC, data->user_data);
@@ -450,7 +448,7 @@ void weather_search_by_ip(const gchar *proxy_host,
     data->proxy_host = proxy_host;
     data->proxy_port = proxy_port;
 
+    g_message("getting http://geoip.xfce.org/");
     weather_http_receive_data("geoip.xfce.org", "/", proxy_host, proxy_port,
                               cb_geolocation, data);
-    return;
 }
