@@ -1,18 +1,19 @@
-/*  Copyright (c) 2003-2007 Xfce Development Team
+/*  Copyright (c) 2003-2012 Xfce Development Team
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -342,7 +343,7 @@ create_summary_tab(xfceweather_data *data)
     APPEND_TEXT_ITEM_REAL(value);
 
     /* sun and moon */
-    APPEND_BTEXT(_("\nAstrological Data\n"));
+    APPEND_BTEXT(_("\nAstronomical Data\n"));
     if (data->astrodata) {
         if (data->astrodata->sun_never_rises) {
             value = g_strdup(_("\tSunrise:\t\tThe sun never rises today.\n"));
@@ -669,21 +670,25 @@ make_forecast(xfceweather_data *data)
 
 
 static GtkWidget *
-create_forecast_tab(xfceweather_data *data,
-                    GtkWidget *window)
+create_forecast_tab(xfceweather_data *data)
 {
     GtkWidget *ebox, *align, *hbox, *scrolled, *table;
-    GdkWindow *win;
+    GdkWindow *window;
     GdkScreen *screen;
     GdkRectangle rect;
-    gint monitor_num, height_needed, height_max;
+    gint monitor_num = 0, height_needed, height_max;
     gdouble factor;
 
-    /* calculate maximum height we may use, subtracting some sane value for safety */
-    screen = gtk_window_get_screen(GTK_WINDOW(window));
-    win = GTK_WIDGET(window)->window;
-    monitor_num = gdk_screen_get_monitor_at_window(GDK_SCREEN(screen), GDK_WINDOW(win));
-    gdk_screen_get_monitor_geometry(GDK_SCREEN(screen), monitor_num, &rect);
+    /* To avoid causing a GDK assertion, determine the monitor
+     * geometry using the weather icon window, which has already been
+     * realized in contrast to the summary window. Then calculate the
+     * maximum height we may use, subtracting some sane value just to
+     * be on the safe side. */
+    window = GDK_WINDOW(gtk_widget_get_window(GTK_WIDGET(data->iconimage)));
+    screen = GDK_SCREEN(gdk_window_get_screen(window));
+    if (G_LIKELY(window && screen))
+        monitor_num = gdk_screen_get_monitor_at_window(screen, window);
+    gdk_screen_get_monitor_geometry(screen, monitor_num, &rect);
 
     /* optimize max height a bit depending on common resolutions */
     if ((rect.height > 600 && rect.height <= 800) || rect.height <= 480)
@@ -777,7 +782,8 @@ create_summary_window (xfceweather_data *data)
     if (G_LIKELY(icon))
         g_object_unref(G_OBJECT(icon));
 
-    if (data->location_name == NULL || data->weatherdata == NULL) {
+    if (data->location_name == NULL || data->weatherdata == NULL ||
+        data->weatherdata->current_conditions == NULL) {
         hbox = gtk_hbox_new(FALSE, 0);
         if (data->location_name == NULL)
             label = gtk_label_new(_("Please set a location in the plugin settings."));
@@ -793,7 +799,7 @@ create_summary_window (xfceweather_data *data)
         notebook = gtk_notebook_new();
         gtk_container_set_border_width(GTK_CONTAINER(notebook), BORDER);
         gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
-                                 create_forecast_tab(data, window),
+                                 create_forecast_tab(data),
                                  gtk_label_new_with_mnemonic(_("_Forecast")));
         gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
                                  create_summary_tab(data),
